.. BSB HDF5 Storage Engine documentation master file, created by
   sphinx-quickstart on Sun Jul  3 14:42:28 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to BSB HDF5 Storage Engine's documentation!
===================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modindex


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
